@@ -1,7 +1,8 @@
-//
-use rusty_engine::prelude::*;
+//! To run this code, clone the rusty_engine repository and run the command:
+//!
+//!     cargo run --release --example sprite
 
-rusty_engine::init!();
+use rusty_engine::prelude::*;
 
 fn main() {
     let mut game = Game::new();
